Installation
============

Dependencies
------------

:math:`\texttt{naif}` only requires `numpy <https://numpy.org/>`__ and `scipy <https://scipy.org/>`__.

Installing
----------

:math:`\texttt{naif}` can be installed from the PyPI module typing::
  
  pip install --user naif

It can also be installed by downloading the source or cloning the GitHub
repository and typing::

  python setup.py install --user

from its root directory. In case you want it installed in a specific directory::
  
  python setup.py install --prefix=/WHERE/YOU/WANT/IT
